@@ -2,8 +2,8 @@ import sqlite3 as sqlite
 import os
 import os.path
 import pkgutil
-from jayson import Jayson
-from pyrustic.manager import constant
+from shared import Jason
+from backstage import constant
 
 
 class MainHost:
@@ -46,13 +46,7 @@ class MainHost:
         return self._dao.script(script, is_file=is_file)
 
     def tables(self):
-        sqlite_prefix = "sqlite_"
-        tables = []
-        data = self._dao.tables()
-        for x in data:
-            if not x[0].startswith(sqlite_prefix):
-                tables.append(x[0])
-        return tables
+        return self._dao.tables()
 
     def db_schema(self):
         db_schema = []
@@ -69,7 +63,7 @@ class MainHost:
         return self._dao.table_content(name)
 
     def _setup(self):
-        shared_folder = os.path.join(constant.SHARED_PYRUSTIC_DATA, "rustiql")
+        shared_folder = os.path.join(constant.PYRUSTIC_DATA_PATH, "rustiql")
         shared_json_path = os.path.join(shared_folder, "rustiql_shared_data.json")
         if not os.path.exists(shared_folder):
             os.makedirs(shared_folder)
@@ -78,7 +72,8 @@ class MainHost:
                                             "misc/default_shared_data.json")
             with open(shared_json_path, "wb") as file:
                 file.write(default_json)
-        self._jasonix = Jayson(shared_json_path)
+        self._jasonix = Jason("rustiql_shared_data",
+                              location=shared_folder)
 
     def _open(self, path):
         dao = None
